@@ -1,4 +1,4 @@
-#ident "$Header: /cvs/jra1mw/org.glite.lb.state-machine/interface/seqcode_aux.h,v 1.4 2010/03/12 16:52:34 zsustr Exp $"
+#ident "$Header: /cvs/jra1mw/org.glite.lb.state-machine/interface/seqcode_aux.h,v 1.5 2012/05/16 08:00:27 mvocu Exp $"
 /*
 Copyright (c) Members of the EGEE Collaboration. 2004-2010.
 See http://www.eu-egee.org/partners for details on the copyright holders.
@@ -26,9 +26,8 @@ int before_deep_resubmission(const char *a, const char *b);
 int same_branch(const char *a, const char *b) ;
 
 int edg_wll_compare_pbs_seq(const char *a,const char *b);
-#define edg_wll_compare_condor_seq edg_wll_compare_pbs_seq
 
-edg_wll_PBSEventSource get_pbs_event_source(const char *pbs_seq_num) ;
+int edg_wll_compare_condor_seq(const char *a,const char *b);
 
 edg_wll_CondorEventSource get_condor_event_source(const char *condor_seq_num) ;
 
