@@ -1,4 +1,4 @@
-#ident "$Header: /cvs/jra1mw/org.glite.lb.state-machine/src/process_event.c,v 1.34.2.2 2012/07/13 12:32:43 valtri Exp $"
+#ident "$Header: /cvs/jra1mw/org.glite.lb.state-machine/src/process_event.c,v 1.37 2012/08/01 13:41:07 zsustr Exp $"
 /*
 Copyright (c) Members of the EGEE Collaboration. 2004-2010.
 See http://www.eu-egee.org/partners for details on the copyright holders.
@@ -49,6 +49,7 @@ int processEvent_Cream(intJobStat *js, edg_wll_Event *e, int ev_seq, int strict,
 int processData_Cream(intJobStat *js, edg_wll_Event *e);
 int processEvent_FileTransfer(intJobStat *js, edg_wll_Event *e, int ev_seq, int strict, char **errstring);
 int processEvent_FileTransferCollection(intJobStat *js, edg_wll_Event *e, int ev_seq, int strict, char **errstring);
+int processEvent_VirtualMachine(intJobStat *js, edg_wll_Event *e, int ev_seq, int strict, char **errstring);
 
 int add_stringlist(char ***lptr, const char *new_item);
 
@@ -82,6 +83,9 @@ int processEvent(intJobStat *js, edg_wll_Event *e, int ev_seq, int strict, char
 			case EDG_WLL_REGJOB_FILE_TRANSFER_COLLECTION:
 				js->pub.jobtype = EDG_WLL_STAT_FILE_TRANSFER_COLLECTION;
 				break;
+			case EDG_WLL_REGJOB_VIRTUAL_MACHINE:
+				js->pub.jobtype = EDG_WLL_STAT_VIRTUAL_MACHINE;
+				break;
 			default:
 				trio_asprintf(errstring,"unknown job type %d in registration",e->regJob.jobtype);
 				return RET_FAIL;
@@ -102,6 +106,8 @@ int processEvent(intJobStat *js, edg_wll_Event *e, int ev_seq, int strict, char
 			return processEvent_FileTransfer(js,e,ev_seq,strict,errstring);
 		case EDG_WLL_STAT_FILE_TRANSFER_COLLECTION:
 			return processEvent_FileTransferCollection(js,e,ev_seq,strict,errstring);
+		case EDG_WLL_STAT_VIRTUAL_MACHINE:
+			return processEvent_VirtualMachine(js,e,ev_seq,strict,errstring);
 		case -1: return RET_UNREG;
 		default: 
 			trio_asprintf(errstring,"undefined job type %d",js->pub.jobtype);
